/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.mail.reader.model;

import java.util.List;

/**
 * @author Scott Lee
 */
public class MessagesDisplay {

	public MessagesDisplay(
		List<Message> messages, int pageNumber, int messagesPerPage,
		int messageCount) {

		_messages = messages;
		_pageNumber = pageNumber;
		_messagesPerPage = messagesPerPage;
		_messageCount = messageCount;
	}

	public int getEndMessageNumber() {
		int messageNumber = _pageNumber * _messagesPerPage;

		if (messageNumber > _messageCount) {
			return _messageCount;
		}
		else {
			return messageNumber;
		}
	}

	public int getMessageCount() {
		return _messageCount;
	}

	public List<Message> getMessages() {
		return _messages;
	}

	public int getPageCount() {
		return (int)(Math.ceil(_messageCount / (double)_messagesPerPage));
	}

	public int getPageNumber() {
		return _pageNumber;
	}

	public int getStartMessageNumber() {
		if (_messageCount == 0) {
			return 0;
		}

		return ((_pageNumber - 1) * _messagesPerPage) + 1;
	}

	private int _messageCount;
	private final List<Message> _messages;
	private final int _messagesPerPage;
	private final int _pageNumber;

}